@@ -484,7 +484,7 @@ class PorticoPreservation(models.Model):
         # increase the CSV field size to accommodate large entries
         csv.field_size_limit(sys.maxsize)
 
-        with StringIO(csv_file.text) as input_file:
+        with StringIO(csv_file) as input_file:
             csv_reader = csv.DictReader(input_file, delimiter='\t',
                                         quoting=csv.QUOTE_NONE)
 
@@ -501,7 +501,7 @@ class PorticoPreservation(models.Model):
                     publisher=publisher
                 )
 
-                logging.info(f'Added {row["Title"]} to '
+                logging.info(f'Added {row["publication_title"]} to '
                              f'{PorticoPreservation.name()} data')
 
 
